// $Modified: Tue Ma 25 14:43:23 20: Mon May 31 19:29:55 2010 by uwer 10 by uwer $
#include "AbstractHathor.h"
#include "HathorPdf.h"
#include <string>
#include <string.h>
#include "LHAPDF/LHAPDF.h"
#include <cstdlib>


using namespace std;
using namespace LHAPDF;


Lhapdf::Lhapdf(){
  PDFname  = "MSTW2008nnlo68cl";
  initPDFSet(PDFname, LHGRID);
}

Lhapdf::Lhapdf(string s){
  if ( s.find(".") == string::npos ){
    PDFname  = s;
    initPDFSet(PDFname, LHGRID);
    return;
  } else {
    int n = s.find('.');
    string hlp(s,0,n);
    string extension(s,n+1);
    PDFname = hlp;
    if ( "LHpdf" == extension ){       
      initPDFSet(PDFname, LHPDF);
      return;
    }
    if ( "LHgrid" == extension ) {
      initPDFSet(PDFname, LHGRID);
      return;
    }
  }

  cerr << "HathorPdf: Cannot load LHA pdf, unknown extension\n";
  cerr << "HathorPdf: use .LHpdf or .LHgrid to specify the respective files\n";
  cerr << "HathorPdf: Without extension .LHgrid files are used.\n"; 
  exit(1);
}

void Lhapdf::GetPdf(double x, double muf, double h[13]){
  

  double res[13];
  xfx(x, muf, res);
  h[AbstractHathor::GLUON] = res[6+ 0];
  h[AbstractHathor::ABOTTOM] = res[6 -5];
  h[AbstractHathor::ACHARM] = res[6 -4];
  h[AbstractHathor::ASTRANGE] = res[6 -3];
  h[AbstractHathor::AUP] = res[6 -2];
  h[AbstractHathor::ADOWN] = res[6 -1];
  h[AbstractHathor::DOWN] = res[6+ 1];
  h[AbstractHathor::UP] = res[6+ 2];
  h[AbstractHathor::STRANGE] = res[6+ 3];
  h[AbstractHathor::CHARM] = res[6+ 4];
  h[AbstractHathor::BOTTOM] = res[6+ 5];

  for (int i=0; i<13; i++){
    h[i] /= x;
  }

}


double Lhapdf::GetAlphas(double mu){
  return(alphasPDF(mu) );
}

void Lhapdf::InitMember(int i){ 
  usePDFMember(i);
}

int Lhapdf::NumberPdf(void){ 
  return(numberPDF());
}

string Lhapdf::GetName(void){
  return(PDFname);
}


/******************************************************************/
extern "C" {
  double mstwgetonepdf_(char *,const int & iset,const double & x,
			const double &q, const int & f);
}

MSTW::MSTW() {
  PDFname = "mstw2008nnlo.68cl";
  if (getenv("MSTWPATH")!=NULL) {
    prefix = std::string(getenv("MSTWPATH"));
  } else {
    prefix = std::string("./");
  }
  strcpy(fullname,(prefix+PDFname).c_str());
  imember = 0;
}

void MSTW::GetPdf(double x, double muf, double h[13]){

  h[AbstractHathor::GLUON] = mstwgetonepdf_(fullname,imember,x,muf,0);
  h[AbstractHathor::ABOTTOM] = mstwgetonepdf_(fullname,imember,x,muf,-5);
  h[AbstractHathor::ACHARM] = mstwgetonepdf_(fullname,imember,x,muf,-4);
  h[AbstractHathor::ASTRANGE] = mstwgetonepdf_(fullname,imember,x,muf,-3);
  h[AbstractHathor::AUP] = mstwgetonepdf_(fullname,imember,x,muf,-2);
  h[AbstractHathor::ADOWN] = mstwgetonepdf_(fullname,imember,x,muf,-1);
  h[AbstractHathor::DOWN] = mstwgetonepdf_(fullname,imember,x,muf,1);
  h[AbstractHathor::UP] = mstwgetonepdf_(fullname,imember,x,muf,2);
  h[AbstractHathor::STRANGE] = mstwgetonepdf_(fullname,imember,x,muf,3);
  h[AbstractHathor::CHARM] = mstwgetonepdf_(fullname,imember,x,muf,4);
  h[AbstractHathor::BOTTOM] = mstwgetonepdf_(fullname,imember,x,muf,5);

  for (int i=0; i<13; i++){
    h[i] /= x;
  }
}

double MSTW::GetAlphas(double mu){ return(1.);}

void MSTW::InitMember(int i){ imember=i;}

int MSTW::NumberPdf(void){return(40);}

string MSTW::GetName(void){
  return(PDFname);
}

